@@ -23,8 +23,6 @@ import zipfile
 from concurrent.futures.thread import ThreadPoolExecutor
 from io import BytesIO, StringIO
 
-from label_sleuth.models.core.languages import Languages
-
 logging.basicConfig(level=logging.INFO,
                     format='%(asctime)s %(levelname)-8s [%(filename)s:%(lineno)d] %(message)s')
 
@@ -426,7 +424,7 @@ def get_positive_predictions(workspace_id):
     all_ready_iterations = current_app.orchestrator_api.get_all_iterations_by_status(workspace_id, category_name,
                                                                                      IterationStatus.READY)
     if len(all_ready_iterations) == 0:
-        return jsonify({'hit_count': 0, "positive_fraction": None,'elements': []})
+        return jsonify({'hit_count': 0, "positive_fraction": None, 'elements': []})
     else:
         # Where labels are applied to duplicate texts (the default behavior), we do not want duplicates to appear in
         # the positive predictions list
@@ -441,7 +439,7 @@ def get_positive_predictions(workspace_id):
         elements_transformed = elements_transformed[start_idx: start_idx + size]
 
         res = {'hit_count': len(positive_predicted_elements), "positive_fraction":
-            iteration.iteration_statistics["positive_fraction"],'elements': elements_transformed}
+            iteration.iteration_statistics["positive_fraction"], 'elements': elements_transformed}
         return jsonify(res)
 
 
@@ -576,8 +574,9 @@ def import_labels(workspace_id):
 
     :param workspace_id:
     """
-    csv_data = StringIO(request.data.decode("utf-8"))  # TODO use request.data also in load_documents()
-    df = pd.read_csv(csv_data, dtype={'labels': str})
+    csv_data = StringIO(request.files['file'].stream.read().decode("utf-8"))
+    df = pd.read_csv(csv_data)
+
     return jsonify(current_app.orchestrator_api.import_category_labels(workspace_id, df))
 
 
