@@ -322,7 +322,8 @@ class OrchestratorApi:
     def _delete_category_models(self, workspace_id, category_name):
         workspace = self.orchestrator_state.get_workspace(workspace_id)
         for idx in range(len(workspace.categories[category_name].iterations)):
-            self.delete_iteration_model(workspace_id, category_name, idx)
+            if workspace.categories[category_name].iterations[idx].model.model_status != ModelStatus.DELETED:
+                self.delete_iteration_model(workspace_id, category_name, idx)
 
     def get_elements_to_label(self, workspace_id: str, category_name: str, count: int, start_index: int = 0) \
             -> List[TextElement]:
@@ -389,8 +390,7 @@ class OrchestratorApi:
                                                                   category_name, new_iteration_index))
         model_status = model.get_model_status(model_id)
         model_info = ModelInfo(model_id=model_id, model_status=model_status, model_type=model_type,
-                               language=self.config.language, train_statistics=train_statistics,
-                               creation_date=datetime.now())
+                               train_statistics=train_statistics, creation_date=datetime.now())
         self.orchestrator_state.add_iteration(workspace_id=workspace_id, category_name=category_name,
                                               model_info=model_info)
     
@@ -631,9 +631,10 @@ class OrchestratorApi:
         else:
             iteration = iterations[iteration_index]
             if iteration.status in [IterationStatus.TRAINING, IterationStatus.MODEL_DELETED, IterationStatus.ERROR]:
-                raise Exception(f"iteration {iteration_index} in workspace '{workspace_id}' "
-                                f"category '{category_name}' is not ready for inference. "
-                                f"(current status is {iteration.status}, model status is {iteration.model.model_status})")
+                raise Exception(
+                    f"iteration {iteration_index} in workspace '{workspace_id}' category '{category_name}' "
+                    f"is not ready for inference. "
+                    f"(current status is {iteration.status}, model status is {iteration.model.model_status})")
     
         model_info = iteration.model
         if model_info.model_status != ModelStatus.READY:
