@@ -27,7 +27,6 @@ from label_sleuth.config import load_config
 from label_sleuth.data_access.core.data_structs import DisplayFields, Document, Label, LABEL_NEGATIVE, LABEL_POSITIVE
 from label_sleuth.data_access.file_based.file_based_data_access import FileBasedDataAccess
 from label_sleuth.data_access.test_file_based_data_access import generate_corpus
-from label_sleuth.models.core.languages import Languages
 from label_sleuth.models.core.model_api import ModelStatus
 from label_sleuth.models.core.catalog import ModelsCatalog
 from label_sleuth.models.core.models_background_jobs_manager import ModelsBackgroundJobsManager
@@ -238,7 +237,7 @@ class TestOrchestratorAPI(unittest.TestCase):
         self.orchestrator_api.create_workspace(workspace_id, dataset_name)
         self.orchestrator_api.create_new_category(workspace_id, category_name, 'some_description')
         get_all_iterations.return_value = \
-            [Iteration(ModelInfo("x", ModelStatus.READY, datetime.now(), ModelsCatalog.RAND, Languages.ENGLISH, {}),
+            [Iteration(ModelInfo("x", ModelStatus.READY, datetime.now(), ModelsCatalog.RAND, {}),
                        IterationStatus.READY, {}, [])] * (NUMBER_OF_MODELS_TO_KEEP+1)
         self.orchestrator_api._delete_old_models(workspace_id, category_name, NUMBER_OF_MODELS_TO_KEEP-1)
 
